require(calibrate)
require(scales)
require(OceanView)
library(RColorBrewer)
require(plotrix)
require(shape)
darkcols <- brewer.pal(8, "Dark2")
palette(darkcols)

#load the datafiles
SW <- read.csv("AllData.csv") 
MBES <- read.csv("transect.csv")
Transect = read.csv("TransectInformation.csv")

#To plot in a break plot
SW$Chl_a[2] <- SW$Chl_a[2] -2 

#Switch stations 2 with 3 for continuous plotting (line drawn from 1-3, then 3-2, since 3 is closer to St 1)
SW$X[SW$X == 3] <- 50
SW$X[SW$X == 2] <- 3
SW$X[SW$X == 50] <- 2

SW = SW[order(SW$X), ]

##################################################################################################################
par (mfrow = c(6, 1), oma = c(4,0,2,0), mar = c(0,8,1,2))
#########
#Fine sand
#########
plot(SW$Distance,SW$SFINES,pch = 18, cex = 2, xaxt = "n", yaxt = "n", 
     xlim = c(0, 1250), ylim = c(10,70),mgp = c(5, 0.5, 0),ann=FALSE)
xleft = c(15,210,416,890,1136)
xright = c(75,282,487,984,1221)
for (i in 1:length(xleft)){
  rect(xleft = xleft[i], xright = xright[i], ybottom = 10, ytop = 70, col = alpha("blue",0.25), lty = 0)
}
xleft = c(98,304,506,746,1014,1243)
xright = c(132,346,568,812,1058,1296)
for (i in 1:length(xleft)){
  rect(xleft = xleft[i], xright = xright[i], ybottom = 10, ytop = 70, col = alpha("blue",0.5), lty = 0)
}
points(SW$Distance[c(1:16,17:34)],SW$SFINES[c(1:16,17:34)],col=c(rep(1,16),rep(2,18)), 
       pch = 18, cex = 2)
lines(SW$Distance[1:7], SW$SFINES[1:7], type = "l", col = 1, lwd=2.5)
lines(SW$Distance[8:16], SW$SFINES[8:16], type = "l", col=1, lwd=2.5)
lines(SW$Distance[17:25], SW$SFINES[17:25], type = "l",col=2, lwd=2.5)
lines(SW$Distance[26:34], SW$SFINES[26:34], type = "l",col=2, lwd=2.5)
arrows(x0=SW$Distance, y0=SW$SFINES+(SW$SFINES.sd), 
       x1=SW$Distance, y1=SW$SFINES-(SW$SFINES.sd), length = 0.05,angle=90, code=3)
legend("topleft",  pch = 18, col = 1:2, legend = c("June","October"), 
       pt.cex = 2, cex = 1,bg="white")
title("Fine sand", line = -1, cex = 1.5, adj=.55)
text(1267,70*0.85,"(A)",cex=1.5)
axis (side = 2, las = 1, cex.axis = 1.2, at = c(10, 30, 50, 70),
      labels=c(10, 30, 50, 70))
mtext(side = 2, outer = FALSE, line=5, "vol. %")
#########
#Median Grain size
#########
plot(SW$Distance,SW$SD50,pch = 18, cex = 2, xaxt = "n", yaxt = "n",
     xlim = c(0, 1250),ylim = c(210,400),mgp = c(5, 0.5, 0),ann=FALSE)
xleft = c(15,210,416,890,1136)
xright = c(75,282,487,984,1221)
for (i in 1:length(xleft)){
  rect(xleft = xleft[i], xright = xright[i], ybottom = 210, ytop = 400, col = alpha("blue",0.25), lty = 0)
}
xleft = c(98,304,506,746,1014,1243)
xright = c(132,346,568,812,1058,1296)
for (i in 1:length(xleft)){
  rect(xleft = xleft[i], xright = xright[i], ybottom = 210, ytop = 400, col = alpha("blue",0.5), lty = 0)
}
points(SW$Distance[c(1:16,17:34)],SW$SD50[c(1:16,17:34)],col=c(rep(1,16),rep(2,18)), 
       pch = 18, cex = 2)
lines(SW$Distance[1:7], SW$SD50[1:7], type = "l", col = 1, lwd=2.5)
lines(SW$Distance[8:16], SW$SD50[8:16], type = "l", col=1, lwd=2.5)
lines(SW$Distance[17:25], SW$SD50[17:25], type = "l",col=2, lwd=2.5)
lines(SW$Distance[26:34], SW$SD50[26:34], type = "l",col=2, lwd=2.5)
arrows(x0=SW$Distance, y0=SW$SD50+(SW$SD50.sd), 
       x1=SW$Distance, y1=SW$SD50-(SW$SD50.sd), length = 0.05,angle=90, code=3)
legend("topleft",  pch = 22, pt.bg=c(alpha("blue",0.25),alpha("blue",0.5),"white","black"), 
       legend = c("Crest","Trough", "Slope"), pt.cex = 2, cex = 1, 
       bg="white")
text(1267,360,"(B)",cex=1.5)
title("D50", line = -1, cex = 1.2, adj=.55)
axis (side = 2, las = 1, cex.axis = 1.2)
mtext(side = 2, outer = FALSE, line=5,expression(paste(mu~m)))
#########
#Organic carbon
#########
plot(SW$Distance,SW$ORG.M,pch = 18, cex = 2, xaxt = "n", yaxt = "n",
     xlim = c(0, 1250),ylim = c(0,.25),mgp = c(5, 0.5, 0),ann=FALSE)
xleft = c(15,210,416,890,1136)
xright = c(75,282,487,984,1221)
for (i in 1:length(xleft)){
  rect(xleft = xleft[i], xright = xright[i], ybottom = 0, ytop = .25, col = alpha("blue",0.25), lty = 0)
}
xleft = c(98,304,506,746,1014,1243)
xright = c(132,346,568,812,1058,1296)
for (i in 1:length(xleft)){
  rect(xleft = xleft[i], xright = xright[i], ybottom = 0, ytop = .25, col = alpha("blue",0.5), lty = 0)
}
points(SW$Distance[c(1:16,17:34)],SW$ORG.M[c(1:16,17:34)],col=c(rep(1,16),rep(2,18)), 
       pch = 18, cex = 2)
lines(SW$Distance[1:7], SW$ORG.M[1:7], type = "l", col = 1, lwd=2.5)
lines(SW$Distance[8:16], SW$ORG.M[8:16], type = "l", col=1, lwd=2.5)
lines(SW$Distance[17:25], SW$ORG.M[17:25], type = "l",col=2, lwd=2.5)
lines(SW$Distance[26:34], SW$ORG.M[26:34], type = "l",col=2, lwd=2.5)
arrows(x0=SW$Distance, y0=SW$ORG.M+(SW$ORG.M), 
       x1=SW$Distance, y1=SW$ORG.M-(SW$ORG.M), length = 0.05,angle=90, code=3)
text(1267, .2*1.05,"(C)",cex=1.5)
title("Org. carbon", line = -1, cex = 1.2, adj=.55)
axis (side = 2, las = 1, cex.axis = 1.2)
mtext(side = 2, outer = FALSE, line=5, "%")
#########
#Chl-a
#########
plot(SW$Distance,SW$Chl_a,pch = 18, cex = 2, axes=F, xlab="", ylab="Day",
     xlim = c(0, 1250),ylim = c(0,3.5),mgp = c(5, 0.5, 0), ann = FALSE)
box()
xleft = c(15,210,416,890,1136)
xright = c(75,282,487,984,1221)
for (i in 1:length(xleft)){
  rect(xleft = xleft[i], xright = xright[i], ybottom = 0, ytop = 3.5, col = alpha("blue",0.25), lty = 0)
}
xleft = c(98,304,506,746,1014,1243)
xright = c(132,346,568,812,1058,1296)
for (i in 1:length(xleft)){
  rect(xleft = xleft[i], xright = xright[i], ybottom = 0, ytop = 3.5, col = alpha("blue",0.5), lty = 0)
}
points(SW$Distance[c(1:16,17:34)],SW$Chl_a[c(1:16,17:34)],col=c(rep(1,16),rep(2,18)), 
       pch = 18, cex = 2)
lines(SW$Distance[1:7], SW$Chl_a[1:7], type = "l", col = 1, lwd=2.5)
lines(SW$Distance[8:16], SW$Chl_a[8:16], type = "l", col=1, lwd=2.5)
lines(SW$Distance[17:25], SW$Chl_a[17:25], type = "l",col=2, lwd=2.5)
lines(SW$Distance[26:34], SW$Chl_a[26:34], type = "l",col=2, lwd=2.5)
text(1267,3.5*.85,"(D)",cex=1.5)
title("Chl-a", line = -1, cex = 1.2, adj=.55)
mtext(side = 2, outer = FALSE, line=5, expression( mu~"g g"^{-1}))
# y-axis
axis(2,at=c(1, 2),labels=c("1","2"), las = 1, cex.axis = 1.2)
axis(2,at=3,labels="5", las = 1, cex.axis = 1.2)
# break axis
axis.break(2, 2, style="gap", brw = 0.03)
par(new=TRUE)
points(SW$Distance[2],SW$CHLA[2], pch = 18, cex = 2 , col = 1)
#########
#Permeability
#########
plot(SW$Distance,SW$permeability,pch = 18, cex = 2, xaxt = "n",  yaxt = "n",
     xlim = c(0, 1250),ylim = c(4.8e-12,3.6e-11),mgp = c(5, 0.5, 0),ann=FALSE)
xleft = c(15,210,416,890,1136)
xright = c(75,282,487,984,1221)
for (i in 1:length(xleft)){
  rect(xleft = xleft[i], xright = xright[i], ybottom = 4.8e-12, ytop = 3.6e-11, col = alpha("blue",0.25), lty = 0)
}
xleft = c(98,304,506,746,1014,1243)
xright = c(132,346,568,812,1058,1296)
for (i in 1:length(xleft)){
  rect(xleft = xleft[i], xright = xright[i], ybottom = 4.8e-12, ytop = 3.6e-11, col = alpha("blue",0.5), lty = 0)
}
points(SW$Distance[c(1:16,17:34)],SW$permeability[c(1:16,17:34)],col=c(rep(1,16),rep(2,18)), 
       pch = 18, cex = 2)
lines(SW$Distance[1:7], SW$permeability[1:7], type = "l", col = 1, lwd=2.5)
lines(SW$Distance[8:16], SW$permeability[8:16], type = "l", col=1, lwd=2.5)
lines(SW$Distance[17:25], SW$permeability[17:25], type = "l",col=2, lwd=2.5)
lines(SW$Distance[26:34], SW$permeability[26:34], type = "l",col=2, lwd=2.5)
arrows(x0=SW$Distance, y0=SW$permeability+(SW$permea.sd), 
       x1=SW$Distance, y1=SW$permeability-(SW$permea.sd), length = 0.05,angle=90, code=3)
text(1267,3.6e-11*0.85,"(E)",cex=1.5)
title("Permeability", line = -1, cex = 1.2, adj=.55)
axis(side=2, at=c(0.5e-11,1.5e-11,2.5e-11,3.5e-11), font=1.2, 
     cex.axis=1.2,las=1, labels=expression("0.5e"^{-11},"1.5e"^{-11},"2.5e"^{-11},"3.5e"^{-11}))
mtext(side = 2, outer = FALSE, line=5,expression(paste(m^{2})))
#########
#Cross section with stations
#########
plot(Transect$Transect.depth~Transect$Transect.distance, type = "l",xlim = c(0, 1250), cex.lab=1.5, cex.axis=1.2, ylim = c(-32.2,-27.5),
     yaxt = "n",xaxt="n", outline = FALSE, font=2,font.lab=2,
     las = 1,mpg=c(5,0.5,0),ann=FALSE)
xleft = c(15,210,416,890,1136)
xright = c(75,282,487,984,1221)
for (i in 1:length(xleft)){
  rect(xleft = xleft[i], xright = xright[i], ybottom = -32.2, ytop = -27.5, col = alpha("blue",0.25), lty = 0)
}
xleft = c(98,304,506,746,1014,1243)
xright = c(132,346,568,812,1058,1296)
for (i in 1:length(xleft)){
  rect(xleft = xleft[i], xright = xright[i], ybottom = -32.2, ytop = -27.5, col = alpha("blue",0.5), lty = 0)
}
points(SW$Distance[c(1:16,17:34)],SW$Depth[c(1:16,17:34)],col=c(rep(1,16),rep(2,18)), 
       pch = 18, cex = 2)
text(1267,-28.3,"(F)",cex=1.5)
title("Water depth", line = -1, cex = 1.2, adj=.55)
axis(side = 1, cex.axis = 1.2)
axis(side = 2, las = 1, cex.axis = 1.2)
mtext(side = 1, outer = TRUE, "Distance (m)", line = 2.5, adj=0.6)
mtext(side = 2, outer = FALSE, "m", line=5)





#####################################################################################################################
#Supplemental figure 2
#####################################################################################################################
par (mfrow = c(7, 1), oma = c(4,0,2,0), mar = c(0,8,1,2))
#########
#Coarse sand
#########
plot(SW$Distance,SW$COARSE,pch = 18, cex = 2, xaxt = "n", yaxt = "n", 
     xlim = c(0, 1250), ylim = c(0,15),mgp = c(5, 0.5, 0),ann=FALSE)
xleft = c(15,210,416,890,1136)
xright = c(75,282,487,984,1221)
for (i in 1:length(xleft)){
  rect(xleft = xleft[i], xright = xright[i], ybottom = 0, ytop = 15, col = alpha("blue",0.25), lty = 0)
}
xleft = c(98,304,506,746,1014,1243)
xright = c(132,346,568,812,1058,1296)
for (i in 1:length(xleft)){
  rect(xleft = xleft[i], xright = xright[i], ybottom = 0, ytop = 15, col = alpha("blue",0.5), lty = 0)
}
points(SW$Distance[c(1:16,17:34)],SW$COARSE[c(1:16,17:34)],col=c(rep(1,16),rep(2,18)), 
       pch = 18, cex = 2)
lines(SW$Distance[1:7], SW$COARSE[1:7], type = "l", col = 1, lwd=2.5)
lines(SW$Distance[8:16], SW$COARSE[8:16], type = "l", col=1, lwd=2.5)
lines(SW$Distance[17:25], SW$COARSE[17:25], type = "l",col=2, lwd=2.5)
lines(SW$Distance[26:34], SW$COARSE[26:34], type = "l",col=2, lwd=2.5)
arrows(x0=SW$Distance, y0=SW$COARSE+(SW$COARSE.sd), 
       x1=SW$Distance, y1=SW$COARSE-(SW$COARSE.sd), length = 0.05,angle=90, code=3)
legend("topleft",  pch = 18, col = 1:2, legend = c("June","October"), 
       pt.cex = 2, cex = 1,bg="white")
title("Coarse sand", line = -1, cex = 1.5, adj=.55)
text(1267,15*0.85,"(A)",cex=1.5)
axis (side = 2, las = 1, cex.axis = 1.2, at = c(10, 30, 50, 70),
      labels=c(10, 30, 50, 70))
mtext(side = 2, outer = FALSE, line=5, "vol. %")
#########
#Medium sand
#########
plot(SW$Distance,SW$MEDIUM,pch = 18, cex = 2, xaxt = "n", yaxt = "n",
     xlim = c(0, 1250),ylim = c(30,80),mgp = c(5, 0.5, 0),ann=FALSE)
xleft = c(15,210,416,890,1136)
xright = c(75,282,487,984,1221)
for (i in 1:length(xleft)){
  rect(xleft = xleft[i], xright = xright[i], ybottom = 30, ytop = 80, col = alpha("blue",0.25), lty = 0)
}
xleft = c(98,304,506,746,1014,1243)
xright = c(132,346,568,812,1058,1296)
for (i in 1:length(xleft)){
  rect(xleft = xleft[i], xright = xright[i], ybottom = 30, ytop = 80, col = alpha("blue",0.5), lty = 0)
}
points(SW$Distance[c(1:16,17:34)],SW$MEDIUM[c(1:16,17:34)],col=c(rep(1,16),rep(2,18)), 
       pch = 18, cex = 2)
lines(SW$Distance[1:7], SW$MEDIUM[1:7], type = "l", col = 1, lwd=2.5)
lines(SW$Distance[8:16], SW$MEDIUM[8:16], type = "l", col=1, lwd=2.5)
lines(SW$Distance[17:25], SW$MEDIUM[17:25], type = "l",col=2, lwd=2.5)
lines(SW$Distance[26:34], SW$MEDIUM[26:34], type = "l",col=2, lwd=2.5)
arrows(x0=SW$Distance, y0=SW$MEDIUM+(SW$MEDIUM.sd), 
       x1=SW$Distance, y1=SW$MEDIUM-(SW$MEDIUM.sd), length = 0.05,angle=90, code=3)
text(1267,80*0.9,"(B)",cex=1.5)
title("Medium sand", line = -1, cex = 1.2, adj=.55)
axis (side = 2, las = 1, cex.axis = 1.2)
mtext(side = 2, outer = FALSE, line=5, "vol. %")
#########
#Very fine sand
#########
plot(SW$Distance,SW$SVFINES,pch = 18, cex = 2, xaxt = "n", yaxt = "n",
     xlim = c(0, 1250),ylim = c(0,10),mgp = c(5, 0.5, 0),ann=FALSE)
xleft = c(15,210,416,890,1136)
xright = c(75,282,487,984,1221)
for (i in 1:length(xleft)){
  rect(xleft = xleft[i], xright = xright[i], ybottom = 0, ytop = 10, col = alpha("blue",0.25), lty = 0)
}
xleft = c(98,304,506,746,1014,1243)
xright = c(132,346,568,812,1058,1296)
for (i in 1:length(xleft)){
  rect(xleft = xleft[i], xright = xright[i], ybottom = 0, ytop = 10, col = alpha("blue",0.5), lty = 0)
}
points(SW$Distance[c(1:16,17:34)],SW$SVFINES[c(1:16,17:34)],col=c(rep(1,16),rep(2,18)), 
       pch = 18, cex = 2)
lines(SW$Distance[1:7], SW$SVFINESES[1:7], type = "l", col = 1, lwd=2.5)
lines(SW$Distance[8:16], SW$SVFINES[8:16], type = "l", col=1, lwd=2.5)
lines(SW$Distance[17:25], SW$SVFINES[17:25], type = "l",col=2, lwd=2.5)
lines(SW$Distance[26:34], SW$SVFINES[26:34], type = "l",col=2, lwd=2.5)
arrows(x0=SW$Distance, y0=SW$SVFINES+(SW$SVFINES.sd), 
       x1=SW$Distance, y1=SW$SVFINES-(SW$SVFINES.sd), length = 0.05,angle=90, code=3)
legend("topleft",  pch = 22, pt.bg=c(alpha("blue",0.25),alpha("blue",0.5),"white","black"), 
       legend = c("Crest","Trough", "Slope"), pt.cex = 2, cex = 1, 
       bg="white")
text(1267,10*0.85,"(C)",cex=1.5)
title("Very fine sand", line = -1, cex = 1.2, adj=.55)
axis (side = 2, las = 1, cex.axis = 1.2)
mtext(side = 2, outer = FALSE, line=5, "vol. %")
#########
#Silt
#########
plot(SW$Distance,SW$SILT,pch = 18, cex = 2, xaxt = "n", yaxt = "n",
     xlim = c(0, 1250),ylim = c(0,30),mgp = c(5, 0.5, 0),ann=FALSE)
xleft = c(15,210,416,890,1136)
xright = c(75,282,487,984,1221)
for (i in 1:length(xleft)){
  rect(xleft = xleft[i], xright = xright[i], ybottom = 0, ytop = 30, col = alpha("blue",0.25), lty = 0)
}
xleft = c(98,304,506,746,1014,1243)
xright = c(132,346,568,812,1058,1296)
for (i in 1:length(xleft)){
  rect(xleft = xleft[i], xright = xright[i], ybottom = 0, ytop = 30, col = alpha("blue",0.5), lty = 0)
}
points(SW$Distance[c(1:16,17:34)],SW$SILT[c(1:16,17:34)],col=c(rep(1,16),rep(2,18)), 
       pch = 18, cex = 2)
lines(SW$Distance[1:7], SW$SILT[1:7], type = "l", col = 1, lwd=2.5)
lines(SW$Distance[8:16], SW$SILT[8:16], type = "l", col=1, lwd=2.5)
lines(SW$Distance[17:25], SW$SILT[17:25], type = "l",col=2, lwd=2.5)
lines(SW$Distance[26:34], SW$SILT[26:34], type = "l",col=2, lwd=2.5)
arrows(x0=SW$Distance, y0=SW$SILT+(SW$SILT.sd), 
       x1=SW$Distance, y1=SW$SILT-(SW$SILT.sd), length = 0.05,angle=90, code=3)
text(1267,30*0.85,"(D)",cex=1.5)
title("Silt", line = -1, cex = 1.2, adj=.55)
axis (side = 2, las = 1, cex.axis = 1.2)
mtext(side = 2, outer = FALSE, line=5, "vol. %")
#########
#D10
#########
plot(SW$Distance,SW$D10,pch = 18, cex = 2, xaxt = "n", yaxt = "n",
     xlim = c(0, 1250),ylim = c(100,300),mgp = c(5, 0.5, 0),ann=FALSE)
xleft = c(15,210,416,890,1136)
xright = c(75,282,487,984,1221)
for (i in 1:length(xleft)){
  rect(xleft = xleft[i], xright = xright[i], ybottom = 100, ytop = 300, col = alpha("blue",0.25), lty = 0)
}
xleft = c(98,304,506,746,1014,1243)
xright = c(132,346,568,812,1058,1296)
for (i in 1:length(xleft)){
  rect(xleft = xleft[i], xright = xright[i], ybottom = 100, ytop = 300, col = alpha("blue",0.5), lty = 0)
}
points(SW$Distance[c(1:16,17:34)],SW$D10[c(1:16,17:34)],col=c(rep(1,16),rep(2,18)), 
       pch = 18, cex = 2)
lines(SW$Distance[1:7], SW$D10[1:7], type = "l", col = 1, lwd=2.5)
lines(SW$Distance[8:16], SW$D10[8:16], type = "l", col=1, lwd=2.5)
lines(SW$Distance[17:25], SW$D10[17:25], type = "l",col=2, lwd=2.5)
lines(SW$Distance[26:34], SW$D10[26:34], type = "l",col=2, lwd=2.5)
arrows(x0=SW$Distance, y0=SW$D10+(SW$D10.sd), 
       x1=SW$Distance, y1=SW$D10-(SW$D10.sd), length = 0.05,angle=90, code=3)
text(1267,300*0.9,"(E)",cex=1.5)
title("D10", line = -1, cex = 1.2, adj=.55)
axis (side = 2, las = 1, cex.axis = 1.2)
mtext(side = 2, outer = FALSE, line=5,expression(paste(mu~m)))
#########
#D90
#########
plot(SW$Distance,SW$D90,pch = 18, cex = 2, xaxt = "n", yaxt = "n",
     xlim = c(0, 1250),ylim = c(350,600),mgp = c(5, 0.5, 0),ann=FALSE)
xleft = c(15,210,416,890,1136)
xright = c(75,282,487,984,1221)
for (i in 1:length(xleft)){
  rect(xleft = xleft[i], xright = xright[i], ybottom = 350, ytop = 600, col = alpha("blue",0.25), lty = 0)
}
xleft = c(98,304,506,746,1014,1243)
xright = c(132,346,568,812,1058,1296)
for (i in 1:length(xleft)){
  rect(xleft = xleft[i], xright = xright[i], ybottom = 350, ytop = 600, col = alpha("blue",0.5), lty = 0)
}
points(SW$Distance[c(1:16,17:34)],SW$D90[c(1:16,17:34)],col=c(rep(1,16),rep(2,18)), 
       pch = 18, cex = 2)
lines(SW$Distance[1:7], SW$D90[1:7], type = "l", col = 1, lwd=2.5)
lines(SW$Distance[8:16], SW$D90[8:16], type = "l", col=1, lwd=2.5)
lines(SW$Distance[17:25], SW$D90[17:25], type = "l",col=2, lwd=2.5)
lines(SW$Distance[26:34], SW$D90[26:34], type = "l",col=2, lwd=2.5)
arrows(x0=SW$Distance, y0=SW$D90+(SW$D90.sd), 
       x1=SW$Distance, y1=SW$D90-(SW$D90.sd), length = 0.05,angle=90, code=3)
text(1267,600*0.92,"(F)",cex=1.5)
title("D90", line = -1, cex = 1.2, adj=.55)
axis (side = 2, las = 1, cex.axis = 1.2)
mtext(side = 2, outer = FALSE, line=5,expression(paste(mu~m)))

#########
#Mode
#########
plot(SW$Distance,SW$MODE,pch = 18, cex = 2, xaxt = "n", yaxt = "n",
     xlim = c(0, 1250),ylim = c(200,350),mgp = c(5, 0.5, 0),ann=FALSE)
xleft = c(15,210,416,890,1136)
xright = c(75,282,487,984,1221)
for (i in 1:length(xleft)){
  rect(xleft = xleft[i], xright = xright[i], ybottom = 200, ytop = 350, col = alpha("blue",0.25), lty = 0)
}
xleft = c(98,304,506,746,1014,1243)
xright = c(132,346,568,812,1058,1296)
for (i in 1:length(xleft)){
  rect(xleft = xleft[i], xright = xright[i], ybottom = 200, ytop = 350, col = alpha("blue",0.5), lty = 0)
}
points(SW$Distance[c(1:16,17:34)],SW$MODE[c(1:16,17:34)],col=c(rep(1,16),rep(2,18)), 
       pch = 18, cex = 2)
lines(SW$Distance[1:7], SW$MODE[1:7], type = "l", col = 1, lwd=2.5)
lines(SW$Distance[8:16], SW$MODE[8:16], type = "l", col=1, lwd=2.5)
lines(SW$Distance[17:25], SW$MODE[17:25], type = "l",col=2, lwd=2.5)
lines(SW$Distance[26:34], SW$MODE[26:34], type = "l",col=2, lwd=2.5)
arrows(x0=SW$Distance, y0=SW$MODE+(SW$MODE.sd), 
       x1=SW$Distance, y1=SW$MODE-(SW$MODE.sd), length = 0.05,angle=90, code=3)
text(1267,350*0.92,"(G)",cex=1.5)
title("Mode", line = -1, cex = 1.2, adj=.55)
axis (side = 2, las = 1, cex.axis = 1.2)
mtext(side = 2, outer = FALSE, line=5,expression(paste(mu~m)))

